@@ -357,12 +357,12 @@ class OTSClient(object):
                     'UpdateRow', table_name, row, condition, return_type, transaction_id
         )
 
-    def delete_row(self, table_name, primary_key, condition, return_type = None, transaction_id = None):
+    def delete_row(self, table_name, row = None, condition = None, return_type = None, transaction_id = None, **kwargs):
         """
         说明：删除一行数据。
 
         ``table_name``是对应的表名。
-        ``primary_key``表示主键。
+        ``row``表示主键。
         ``condition``表示执行操作前做条件检查，满足条件才执行，是tablestore.metadata.Condition类的实例。
         目前支持两种条件检测，一是对行的存在性进行检查，检查条件包括：'IGNORE'，'EXPECT_EXIST'和'EXPECT_NOT_EXIST';二是对属性列值的条件检测。
 
@@ -374,12 +374,20 @@ class OTSClient(object):
         示例：
 
             primary_key = [('gid',1), ('uid',101)]
+            row = Row(primary_key)
             condition = Condition('IGNORE')
-            consumed, return_row = client.delete_row('myTable', primary_key, condition)
+            consumed, return_row = client.delete_row('myTable', row, condition)
         """
 
+        primary_key = kwargs.get('primary_key', None)
+        # row不为空时，优先使用row参数，但是传参需要primary_key
+        if row is not None:
+            primary_key = row
+        # 传参为Row时，取出primary_key
+        if isinstance(primary_key, Row):
+            primary_key = primary_key.primary_key
         return self._request_helper(
-                    'DeleteRow', table_name, primary_key, condition, return_type, transaction_id
+            'DeleteRow', table_name, primary_key, condition, return_type, transaction_id
         )
     
     def exe_sql_query(self,query):
@@ -902,3 +910,34 @@ class OTSClient(object):
         """
 
         return self._request_helper('AbortTransaction', transaction_id)
+
+    def put_timeseries_data(self, timeseriesTableName: str, timeseriesRows: TimeseriesRow) -> PutTimeseriesDataResponse:
+
+        return self._request_helper('PutTimeseriesData', timeseriesTableName, timeseriesRows)
+
+    def create_timeseries_table(self, request: CreateTimeseriesTableRequest):
+        return self._request_helper('CreateTimeseriesTable', request)
+
+    def list_timeseries_table(self) -> list:
+        return self._request_helper('ListTimeseriesTable')
+
+    def delete_timeseries_table(self, timeseries_table_name: str):
+        return self._request_helper('DeleteTimeseriesTable', timeseries_table_name)
+
+    def describe_timeseries_table(self, timeseries_table_name: str) -> DescribeTimeseriesTableResponse:
+        return self._request_helper('DescribeTimeseriesTable', timeseries_table_name)
+
+    def update_timeseries_table(self, timeseries_meta: TimeseriesTableMeta):
+        return self._request_helper('UpdateTimeseriesTable', timeseries_meta)
+
+    def update_timeseries_meta(self, request: UpdateTimeseriesMetaRequest) -> UpdateTimeseriesMetaResponse:
+        return self._request_helper('UpdateTimeseriesMeta', request)
+
+    def delete_timeseries_meta(self, request: DeleteTimeseriesMetaRequest) -> DeleteTimeseriesMetaResponse:
+        return self._request_helper('DeleteTimeseriesMeta', request)
+
+    def query_timeseries_meta(self, request: QueryTimeseriesMetaRequest) -> QueryTimeseriesMetaResponse:
+        return self._request_helper('QueryTimeseriesMeta', request)
+
+    def get_timeseries_data(self, request: GetTimeseriesDataRequest) -> GetTimeseriesDataResponse:
+        return self._request_helper('GetTimeseriesData', request)
